/** \brief XQSplashScreen class source file
	\file XQSplashScreen.cpp
	\version 0.1
	\author Chritophe SAUVEUR <christophe@xhaleera.com>
	
	Source code released under the terms of the GNU GPL v2.
	See license.txt or connect to http://www.gnu.org/licenses/gpl.txt for more
	information.
*/

#include "XQSplashScreen.h"

#include <QTimer>

XQSplashScreen::XQSplashScreen(const QPixmap& pixmap, unsigned int minimalDisplayDuration, Qt::WindowFlags f)
	: QSplashScreen(pixmap, f)
{
	init(minimalDisplayDuration);
}

XQSplashScreen::XQSplashScreen(QWidget *parent, const QPixmap& pixmap, unsigned int minimalDisplayDuration, Qt::WindowFlags f)
	: QSplashScreen(parent, pixmap, f)
{
	init(minimalDisplayDuration);
}

void
XQSplashScreen::delayedFinish(QWidget *next)
{
	if (timerFired)
	{
		if (next)
			QSplashScreen::finish(next);
		else if (nextWidget)
			QSplashScreen::finish(nextWidget);
	}
	else
		nextWidget = next;
}

void
XQSplashScreen::init(unsigned int minimalDisplayDuration)
{
	nextWidget = 0;
	setWindowModality(Qt::ApplicationModal);
	if (minimalDisplayDuration != 0 && !pixmap().isNull())
	{
		timerFired = false;
		QTimer::singleShot(minimalDisplayDuration, this, SLOT(finish()));
	}
	else
		timerFired = true;
}

void
XQSplashScreen::finish(void)
{
	timerFired = true;
	delayedFinish();
}
